@@ -1,24 +1,19 @@
 /*
- * Copyright (C) 1996, 1997, 2000, 2001,
- *                             Nara Institute of Science and Technology
+ * Copyright (c) 2003 Nara Institute of Science and Technology
  * All rights reserved.
  *
  * Redistribution and use in source and binary forms, with or without
  * modification, are permitted provided that the following conditions
  * are met:
+ *
  * 1. Redistributions of source code must retain the above copyright
- *    notice, this list of conditions and the following disclaimer.
+ *   notice, this list of conditions and the following disclaimer.
  * 2. Redistributions in binary form must reproduce the above copyright
  *    notice, this list of conditions and the following disclaimer in the
  *    documentation and/or other materials provided with the distribution.
- * 3. All advertising materials mentioning features or use of this software
- *    must display the following acknowledgement:
- *      This product includes software developed by Nara Institute of 
- *      Science and Technology.
- * 4. The name Nara Institute of Science and Technology may not be used to
- *    endorse or promote products derived from this software without specific
- *    prior written permission.
- *    
+ * 3. The name Nara Institute of Science and Technology may not be used to
+ *    endorse or promote products derived from this software without
+ *    specific prior written permission.
  *
  * THIS SOFTWARE IS PROVIDED BY Nara Institute of Science and Technology 
  * ``AS IS'' AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT 
@@ -32,9 +27,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * Author: A.Kitauchi <akira-k@is.aist-nara.ac.jp>, Apr. 1997
- * $Id: chasen.c,v 1.18 2003/06/04 14:19:35 kazuma-t Exp $
- *
+ * $Id: chasen.c,v 1.20 2003/07/08 17:08:49 kazuma-t Exp $
  */
 
 #include "config.h"
@@ -170,7 +163,7 @@ usage(FILE * fp)
 	"    -F format      show morpheme with formatted output\n",
 	"    -Fh            print help of -F option\n",
 	"  (miscellaneous)\n",
-	"    -i schema      encoding schema.\n",
+	"    -i encoding    character encoding.\n",
         "                   e: EUC-JP, s: Shift_JIS, ",
 	"w: UTF-8, a: ISO-8859-1\n",
 	"    -j             Japanese sentence mode\n",
