@@ -1,5 +1,5 @@
 /*
- * $Id: chalib.h,v 1.44 2003/07/28 06:35:22 kazuma-t Exp $
+ * $Id: chalib.h,v 1.45 2003/08/04 11:08:34 kazuma-t Exp $
  */
 
 #ifndef __CHALIB_H__
@@ -56,6 +56,8 @@ typedef struct _mrph_data_t {
     short stem_len;
     char *reading;
     char *pron;
+    short reading_len;
+    short pron_len;
     char *base;
     char *info;
     long compound;
