@@ -27,7 +27,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: init.c,v 1.34 2003/07/15 06:46:50 kazuma-t Exp $
+ * $Id: init.c,v 1.35 2003/08/15 01:56:50 kazuma-t Exp $
  */
 
 #include "chalib.h"
@@ -330,6 +330,9 @@ cha_init(void)
      */
     cha_set_cost_width(COST_WIDTH_DEFAULT);
 
+    if (cha_literal[0][2] == NULL)
+	cha_set_encode("");
+
     cha_read_grammar_dir();
     cha_read_grammar(NULL, 1, 1);
 
