@@ -27,14 +27,18 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: iotool.c,v 1.16 2003/07/08 17:08:49 kazuma-t Exp $
+ * $Id: iotool.c,v 1.17 2003/08/13 13:55:19 kazuma-t Exp $
  */
 
+#include "config.h"
+
 #include <stdio.h>
 #include <stdarg.h>
+#ifdef HAVE_WINDOWS_H
+#include <windows.h>
+#endif
 #include "chadic.h"
 #include "literal.h"
-#include "config.h"
 
 #ifdef PATHTYPE_MSDOS
 #define RCFILE "\\chasenrc"
@@ -46,6 +50,12 @@
 
 #define OLDRCFILE "/.jumanrc"
 
+#if defined HAVE_WINDOWS_H && !defined __CYGWIN__
+#define REG_PATH "Software\\NAIST\\ChaSen"
+#define REG_RC "chasenrc"
+#define REG_GRAMMAR "grammar"
+#endif
+
 int Cha_lineno, Cha_lineno_error;
 int Cha_errno = 0;
 
@@ -459,9 +469,12 @@ cha_fopen_rcfile(void)
      * -R option (standard alone) 
      */
     if (!strcmp(chasenrc_path, "*")) {
-	/*
-	 * RCPATH in rcpath.h 
-	 */
+#if defined HAVE_WINDOWS_H && !defined __CYGWIN__
+	if ((cha_read_registry(REG_PATH, REG_RC, chasenrc_path) != NULL) &&
+	    ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)) {
+	    return fp;
+	}
+#endif
 	strcpy(chasenrc_path, RCPATH);
 	if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
 	    return fp;
@@ -519,9 +532,12 @@ cha_fopen_rcfile(void)
     */
 #endif /* PATHTYPE_MSDOS */
 
-    /*
-     * RCPATH in rcpath.h 
-     */
+#if defined HAVE_WINDOWS_H && !defined __CYGWIN__
+    if ((cha_read_registry(REG_PATH, REG_RC, chasenrc_path) != NULL) &&
+	((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)) {
+	return fp;
+    }
+#endif
     strcpy(chasenrc_path, RCPATH);
 
     if ((fp = cha_fopen(chasenrc_path, "r", -1)) != NULL)
@@ -539,6 +555,17 @@ cha_fopen_rcfile(void)
     return NULL;
 }
 
+static void
+add_delimiter(char *string)
+{
+    char *s = string + strlen(string);
+
+    if (s[-1] != PATH_DELIMITER) {
+	s[0] = PATH_DELIMITER;
+	s[1] = '\0';
+    }
+}
+
 /*
  * read .chasenrc and set grammar directory
  */
@@ -556,23 +583,51 @@ cha_read_grammar_dir(void)
 	s = cha_s_atom(cha_car(cell));
 	if (cha_litmatch(s, 1, STR_GRAM_FILE)) {
 	    strcpy(grammar_dir, cha_s_atom(cha_car(cha_cdr(cell))));
-	    s = grammar_dir + strlen(grammar_dir);
-	    if (s[-1] != PATH_DELIMITER) {
-		s[0] = PATH_DELIMITER;
-		s[1] = '\0';
-	    }
+	    add_delimiter(grammar_dir);
 	    break;
 	}
     }
 
     if (grammar_dir[0] == '\0') {
 	char *s;
+
+#if defined HAVE_WINDOWS_H && !defined __CYGWIN__
+	if (cha_read_registry(REG_PATH, REG_GRAMMAR,
+			      grammar_dir) != NULL) {
+	    if (grammar_dir[0] != '\0')
+		add_delimiter(grammar_dir);
+	} else {
+#endif
 	strcpy(grammar_dir, chasenrc_path);
 	if ((s = strrchr(grammar_dir, PATH_DELIMITER)) != NULL)
 	    s[1] = '\0';
 	else
 	    grammar_dir[0] = '\0';
+#if defined HAVE_WINDOWS_H && !defined __CYGWIN__
+	}
+#endif
     }
 
     fclose(fp);
 }
+
+char *
+cha_read_registry(char *path, char *name, char *val)
+{
+#if defined HAVE_WINDOWS_H && !defined __CYGWIN__
+    HKEY hKey;
+    DWORD size = CHA_FILENAME_LEN;
+
+    if ((RegOpenKeyEx(HKEY_CURRENT_USER, path, 0, 
+		      KEY_QUERY_VALUE, &hKey) == ERROR_SUCCESS) &&
+	(RegQueryValueEx(hKey, name, NULL, NULL, (LPBYTE)val, &size) ==
+	 ERROR_SUCCESS)) {
+	RegCloseKey(hKey);
+    } else
+	val = NULL;
+
+    return val;
+#else
+    return NULL;
+#endif
+}
