@@ -27,7 +27,7 @@
  * NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS 
  * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
  *
- * $Id: print.c,v 1.48 2003/07/28 06:35:22 kazuma-t Exp $
+ * $Id: print.c,v 1.53 2003/08/11 05:53:36 kazuma-t Exp $
  */
 
 #include <stdarg.h>
@@ -97,12 +97,14 @@ get_mrph_data(mrph_t *mrph, mrph_data_t *data)
 	data->stem_len = d.stem_len;
 	p += mrph->dat_index + sizeof(da_dat_t);
 	data->reading = p;
-	p += d.reading_len + 1;
+	p += ((d.reading_len >= 0) ? d.reading_len : 0) + 1;
 	data->pron = p;
-	p += d.pron_len + 1;
+	p += ((d.pron_len >= 0) ? d.pron_len : 0) + 1;
 	data->base = p;
 	p += d.base_len + 1;
 	data->info = p;
+	data->reading_len = d.reading_len;
+	data->pron_len = d.pron_len;
     }
 
     return data;
@@ -547,8 +549,10 @@ print_anno(int path_num, char *format)
 	    (Cha_anno_info[anno_no].hinsi
 	     || Cha_anno_info[anno_no].format)) {
 	    mrph.headword = Cha_tokenizer->string + pos_end;
-	    mrph.headword_len =
+	    mrph.headword_len = mrph.stem_len =
 		cha_tok_char_type_len(Cha_tokenizer, pos_end);
+	    mrph.reading_len = -1;
+	    mrph.pron_len = -1;
 	    mrph.reading = "";
 	    mrph.pron = "";
 	    mrph.base = "";
@@ -725,23 +729,22 @@ cha_printf_mrph(int path_num, mrph_data_t *mrph, char *format)
 	case 'y':		/* Japanese Reading (surface form) */
 	case 'Y':		/* Japanese Reading (base form) */
 	case 'r':
-	    if (mrph->stem_len < 0 || mrph->reading[0]) {
+	    word_str[0] = '\0';
+	    if (mrph->reading_len >= 0) {
 		if (s[0] != 'r' && s[1] != '0')
 		    extract_yomi1(word_str, mrph->reading);
 		else
 		    strcpy(word_str, mrph->reading);
-	    } else {
-		memcpy(word_str, mrph->headword, mrph->stem_len);
-		word_str[mrph->stem_len] = '\0';
-	    }
-	    if (mrph->inf_type > 0 && mrph->stem_len >= 0) {
-		if (*s != 'Y')
-		    strcat(word_str,
-			   Cha_form[mrph->inf_type][mrph->inf_form].ygobi);
-		else
-		    strcat(word_str,
-			   Cha_form[mrph->inf_type][Cha_type[mrph->inf_type].
-						    basic].ygobi);
+		if (mrph->inf_type > 0 && mrph->stem_len >= 0) {
+		    if (*s != 'Y')
+			strcat(word_str,
+			       Cha_form[mrph->inf_type]
+			       [mrph->inf_form].ygobi);
+		    else
+			strcat(word_str,
+			       Cha_form[mrph->inf_type]
+			       [Cha_type[mrph->inf_type].basic].ygobi);
+		}
 	    }
 	    eword = word_str;
 	    if (*s != 'r') {
@@ -767,28 +770,20 @@ cha_printf_mrph(int path_num, mrph_data_t *mrph, char *format)
 	    break;
 	case 'a':		/* Japanese pronunciation (surface form) */
 	case 'A':		/* Japanese pronunciation (base form) */
-	    if (mrph->stem_len < 0 || mrph->pron[0]) {
+	    word_str[0] = '\0';
+	    if (mrph->pron_len >= 0) {
 		if (s[1] != '0')
 		    extract_yomi1(word_str, mrph->pron);
 		else
 		    strcpy(word_str, mrph->pron);
-	    } else if (mrph->reading[0]) {
-		if (s[1] != '0')
-		    extract_yomi1(word_str, mrph->reading);
-		else
-		    strcpy(word_str, mrph->reading);
-	    } else {
-		memcpy(word_str, mrph->headword, mrph->stem_len);
-		word_str[mrph->stem_len] = 0;
-	    }
-	    if (mrph->inf_type > 0 && mrph->stem_len >= 0) {
-		if (*s != 'A')
-		    strcat(word_str,
-			   Cha_form[mrph->inf_type][mrph->inf_form].pgobi);
-		else
-		    strcat(word_str,
-			   Cha_form[mrph->inf_type][Cha_type[mrph->inf_type].
-						    basic].pgobi);
+		if (mrph->inf_type > 0 && mrph->stem_len >= 0) {
+		    if (*s != 'A')
+			strcat(word_str, Cha_form[mrph->inf_type]
+			       [mrph->inf_form].pgobi);
+		    else
+			strcat(word_str, Cha_form[mrph->inf_type]
+			       [Cha_type[mrph->inf_type].basic].pgobi);
+		}
 	    }
 	    eword = word_str;
 	    if (s[1] == '0' || s[1] == '1')
@@ -1037,9 +1032,11 @@ print_mrph(int path_num, mrph_data_t *mrph, char *format)
 	while (has_next) {
 	    has_next = get_compound(&data, headword, mrph->darts, index);
 	    if (!has_next) {
-		data.inf_form = mrph->inf_form;
-		data.headword_len +=
-		    strlen(Cha_form[mrph->inf_type][mrph->inf_form].gobi);
+		if (mrph->inf_type > 0 && mrph->stem_len >= 0) {
+		    data.inf_form = mrph->inf_form;
+		    data.headword_len +=
+			strlen(Cha_form[mrph->inf_type][mrph->inf_form].gobi);
+		}
 		data.con_tbl = mrph->con_tbl;
 	    }
 	    cha_printf_mrph(path_num, &data, format);
