@@ -1,10 +1,11 @@
 /*
  * makemat.c - make table file and matrix file
  *
- * $Id: makemat.c,v 1.11 2003/02/13 14:21:37 kazuma-t Exp $
+ * $Id: makemat.c,v 1.12 2003/06/04 14:19:35 kazuma-t Exp $
  */
 
 #include "chadic.h"
+#include "literal.h"
 
 #define CTYPE_MAX        500
 #define REN_TBL_MAX      5000
@@ -127,8 +128,7 @@ get_pair2(chasen_cell_t * cell, rensetu_pair2_t * pair)
 	return;
 
     s = cha_s_atom(cha_car(cell_p));
-    if (strmatch2(s, JSTR_BOS, ESTR_BOS) ||
-	strmatch2(s, JSTR_EOS, ESTR_EOS)) {
+    if (cha_litmatch(s, 2, STR_BOS, STR_EOS)) {
 	pair->hinsi = NULL;
 	return;
     }
@@ -799,15 +799,25 @@ main(int argc, char *argv[])
     FILE *fpc;
     int lines;
     char *con_filename;
-
-    if (argc < 2)
-	con_filename = CONNECT_FILE;
-    else
-	con_filename = argv[1];
-
+    int c;
 
     cha_set_progpath(argv[0]);
 
+    cha_set_encode("");
+    while ((c = cha_getopt(argv, "i:", stderr)) != EOF) {
+	switch (c) {
+	case 'i':
+	    cha_set_encode(Cha_optarg);
+	    break;
+	}
+    }
+    argv += Cha_optind;
+
+    if (argv[0] == NULL)
+	con_filename = CONNECT_FILE;
+    else
+	con_filename = argv[0];
+
     /*
      * .chasenrc ɤ߹ɬפʤ 
      */
